=======
History
=======

0.2.0 (2018-11-15)
------------------
* optimized exit check mechanism, can exit quickly now.
* exts load interface has no parameters now.
* support multiple splited configure files.
* support extension groups.

0.1.3 (2018-10-27)
------------------

* remove global env object, you can reference by event.env.
* fix finchan.exts.timer_souce schedule format for month/year/week.

0.1.2 (2018-10-01)
------------------

* Fix pypi package.
* Support docker run.
* Add SYSTEM_EXITING event.

0.1.1 (2018-09-22)
------------------

* First release on PyPI.
